@@ -1,7 +1,5 @@
-#coding=utf-8
-
 from agileutil.compress import Compress
 
 class RpcCompress(Compress):
 
-    enableCompressLen = 1024 * 4 #大于4k开启压缩
+    enableCompressLen = 1024 * 4 #more than 4k enable compress
